@@ -37,10 +37,12 @@ def handle_col(df):
             break
         elif cmd == '6':
             threshold = input('请输入字符：')
+            df[col_name] = df[col_name].astype(str)
             df_new = df.loc[df[col_name].str.contains(threshold) == True]
             break
         elif cmd == '7':
             threshold = input('请输入字符：')
+            df[col_name] = df[col_name].astype(str)
             df_new = df.loc[df[col_name].str.contains(threshold) == False]
             break
         else:
@@ -57,5 +59,7 @@ def extract_csv(df, csv):
         if row == 0:
             print('\n没有任何数据符合当前条件！')
         elif go_on != '1':
-            df.to_csv(csv.replace('.csv', '_extract' + '.csv'), index=False)
+            output_name = csv.replace('.csv', '_extract' + '.csv')
+            df.to_csv(output_name, index=False)
+            print('csv已保存，请查看：%s' % output_name)
             break
