@@ -31,4 +31,6 @@ def top_csv(df, csv):
         else:
             print('\n输入错误，请输入1至%s之间的数！' % row)
     top_df = df.sort_values(col_name, ascending=assending)[:top_num]
-    top_df.to_csv(csv.replace('.csv', '_top'+str(top_num)+'.csv'), index=False)
+    output_name = csv.replace('.csv', '_top'+str(top_num)+'.csv')
+    top_df.to_csv(output_name, index=False)
+    print('csv已保存，请查看：%s' % output_name)
